==> nextcloud-30.0.13.tgz: nextcloud/apps/systemtags/l10n/es.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etiqueta de sistema %1$s añadida por el sistema",
    "Added system tag {systemtag}" : "Se añadió la etiqueta de sistema {systemtag}",
    "Added system tag %1$s" : "Se añadió la etiqueta del sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s añadió la etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} añadió la etiqueta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etiqueta de sistema %1$s eliminada por el sistema",
    "Removed system tag {systemtag}" : "Eliminada etiqueta de sistema {systemtag}",
    "Removed system tag %1$s" : "Eliminada etiqueta de sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s eliminó la etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eliminó la etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Usted creó la etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Usted creó la etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creó la etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Usted eliminó la etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Usted eliminó la etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eliminó la etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eliminó la etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Usted actualizó la etiqueta de sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Usted actualizó la etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizó la etiqueta de sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizó la etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etiqueta de sistema %2$s  añadida a %1$s por el sistema",
    "System tag {systemtag} was added to {file} by the system" : "Etiqueta de sistema {systemtag} añadida a {file} por el sistema",
    "You added system tag %2$s to %1$s" : "Usted añadió la etiqueta de sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Usted añadió la etiqueta de sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s agregó la etiqueta de sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} agregó la etiqueta de sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etiqueta de sistema %2$s eliminada de %1$s por el sistema",
    "System tag {systemtag} was removed from {file} by the system" : "Etiqueta de sistema {systemtag} eliminada de {file} por el sistema",
    "You removed system tag %2$s from %1$s" : "Ha removido la etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Ha removido la etiqueta de sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s removió la etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} removió la etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restringido)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "Se han modificado las <strong>etiquetas de sistema</strong> de un archivo",
    "Files" : "Archivos",
    "Tags" : "Etiquetas",
    "All tagged %s …" : "Todos etiquetados %s …",
    "tagged %s" : "Etiquetados %s",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among people." : "Funcionalidad de etiquetado colaborativo que comparte etiquetas entre usuarios.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidad de etiquetado colaborativo que comparte etiquetas entre usuarios. Ideal para equipos.\n        (Si eres un proveedor con una instalación de múltiples inquilinos, se recomienda desactivar esta aplicación, ya que las etiquetas son compartidas.)",
    "Public" : "Público",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Created tag" : "Etiqueta creada",
    "Failed to create tag" : "Fallo al crear etiqueta",
    "Updated tag" : "Etiqueta actualizada",
    "Failed to update tag" : "Fallo al actualizar la etiqueta",
    "Deleted tag" : "Etiqueta eliminada",
    "Failed to delete tag" : "Fallo al borrar etiqueta",
    "Create or edit tags" : "Crear o editar etiquetas",
    "Search for a tag to edit" : "Buscar la etiqueta a editar",
    "Collaborative tags …" : "Etiquetas colaborativas ...",
    "No tags to select" : "No hay etiquetas para seleccionar",
    "Tag name" : "Nombre de la etiqueta",
    "Tag level" : "Nivel de la etiqueta",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Delete" : "Borrar",
    "Reset" : "Restablecer",
    "Loading …" : "Cargando …",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} será establecida y {tag2} se eliminará de 1 archivo.","{tag1} será establecida y {tag2} será eliminada de {count} archivos.","{tag1} será establecida y {tag2} será eliminada de {count} archivos."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag}se establecerá en 1 archivo.","{tag} se establecerá en {count} archivos.","{tag} se establecerá en {count} archivos."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} se eliminará de 1 archivo.","{tag} se eliminará de {count} archivos.","{tag} se eliminará de {count} archivos."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} y {lastTag} se establecerán en 1 archivo.","{tags} y {lastTag} se establecerán en {count} archivos.","{tags} y {lastTag} se establecerán en {count} archivos."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} y {lastTag} serán eliminadas de 1 archivo.","{tags} y {lastTag} serán eliminadas de {count} archivos.","{tags} y {lastTag} serán eliminadas de {count} archivos."],
    "{displayName} (hidden)" : "{displayName} (oculto)",
    "{displayName} (restricted)" : "{displayName} (restringido) ",
    "Only admins can create new tags" : "Solo los administradores pueden crear etiquetas nuevas",
    "Failed to apply tags changes" : "Error al guardar los cambios de la etiqueta",
    "File tags modification canceled" : "Modificación de las etiquetas del archivo cancelada",
    "Manage tags" : "Gestionar etiquetas",
    "Applying tags changes…" : "Aplicando cambios a las etiquetas...",
    "Search or create tag" : "Buscar o crear etiqueta",
    "Search tag" : "Buscar etiqueta",
    "Change tag color" : "Cambiar color de etiqueta",
    "Create new tag" : "Crear nueva etiqueta",
    "Select or create tags to apply to all selected files" : "Selecciona o crea etiquetas para aplicar a los archivos seleccionados",
    "Select tags to apply to all selected files" : "Seleccione las etiquetas que se aplicarán a todos los archivos",
    "Cancel" : "Cancelar",
    "Apply changes" : "Aplicar cambios",
    "Failed to load tags" : "Fallo al cargar etiquetas",
    "Failed to load selected tags" : "Fallo al cargar las etiquetas seleccionadas",
    "Failed to select tag" : "Fallo al seleccionar etiqueta",
    "System admin disabled tag creation. You can only use existing ones." : "El administrador del sistema ha desactivado la creación de etiquetas. Solo puedes usar las que ya existen.",
    "Loading collaborative tags …" : "Cargando etiquetas colaborativas …",
    "Search or create collaborative tags" : "Buscar o crear etiquetas colaborativas",
    "No tags to select, type to create a new tag" : "No hay etiquetas para seleccionar, escriba para crear una etiqueta nueva",
    "Unable to update setting" : "No se ha podido actualizar la configuración",
    "System tag creation is now restricted to administrators" : "La creación de etiquetas del sistema está limitada a administradores",
    "System tag creation is now allowed for everybody" : "Todos los usuarios pueden crear etiquetas del sistema",
    "System tag management" : "Administración de etiquetas del sistema",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Si está habilitado, sólo los administradores podrán crear y editar etiquetas. Las demás cuentas todavía serán capaces de asignarlas o eliminarlas de los archivos.",
    "Restrict tag creation and editing to administrators" : "Restringir la creación y edición de etiquetas a los administradores",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Las etiquetas colaborativas están disponibles para todos los usuarios. Las etiquetas restringidas son visibles para los usuarios, pero no pueden ser asignadas por ellos. Las etiquetas invisibles son para uso interno, pues los usuarios no pueden verlas ni asignarlas.",
    "Assigned collaborative tags" : "Etiquetas colaborativas asignadas",
    "Open in Files" : "Abrir en Archivos",
    "List of tags and their associated files and folders." : "Lista de etiquetas y sus carpetas y archivos asociados.",
    "No tags found" : "No se encontraron etiquetas",
    "Tags you have created will show up here." : "Las etiquetas que haya creado aparecerán aquí.",
    "Failed to load tag" : "Error al cargar etiqueta",
    "Failed to load last used tags" : "Fallo al cargar las etiquetas recientemente utilizadas",
    "Missing \"Content-Location\" header" : "Falta el encabezado \"Content-Location\"",
    "A tag with the same name already exists" : "Ya existe una etiqueta con el mismo nombre",
    "Failed to load tags for file" : "Fallo al cargar las etiquetas del archivo",
    "Failed to set tag for file" : "Fallo al asignar la etiqueta al archivo",
    "Failed to delete tag for file" : "Fallo al borrar la etiqueta del archivo"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.9.tgz: nextcloud/apps/systemtags/l10n/es.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etiqueta de sistema %1$s añadida por el sistema",
    "Added system tag {systemtag}" : "Se añadió la etiqueta de sistema {systemtag}",
    "Added system tag %1$s" : "Se añadió la etiqueta del sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s añadió la etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} añadió la etiqueta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etiqueta de sistema %1$s eliminada por el sistema",
    "Removed system tag {systemtag}" : "Eliminada etiqueta de sistema {systemtag}",
    "Removed system tag %1$s" : "Eliminada etiqueta de sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s eliminó la etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eliminó la etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Usted creó la etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Usted creó la etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creó la etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Usted eliminó la etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Usted eliminó la etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eliminó la etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eliminó la etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Usted actualizó la etiqueta de sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Usted actualizó la etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizó la etiqueta de sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizó la etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etiqueta de sistema %2$s  añadida a %1$s por el sistema",
    "System tag {systemtag} was added to {file} by the system" : "Etiqueta de sistema {systemtag} añadida a {file} por el sistema",
    "You added system tag %2$s to %1$s" : "Usted añadió la etiqueta de sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Usted añadió la etiqueta de sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s agregó la etiqueta de sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} agregó la etiqueta de sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etiqueta de sistema %2$s eliminada de %1$s por el sistema",
    "System tag {systemtag} was removed from {file} by the system" : "Etiqueta de sistema {systemtag} eliminada de {file} por el sistema",
    "You removed system tag %2$s from %1$s" : "Ha removido la etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Ha removido la etiqueta de sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s removió la etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} removió la etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restringido)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "Se han modificado las <strong>etiquetas de sistema</strong> de un archivo",
    "Files" : "Archivos",
    "Tags" : "Etiquetas",
    "All tagged %s …" : "Todos etiquetados %s …",
    "tagged %s" : "Etiquetados %s",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among people." : "Funcionalidad de etiquetado colaborativo que comparte etiquetas entre usuarios.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidad de etiquetado colaborativo que comparte etiquetas entre usuarios. Ideal para equipos.\n        (Si eres un proveedor con una instalación de múltiples inquilinos, se recomienda desactivar esta aplicación, ya que las etiquetas son compartidas.)",
    "Public" : "Público",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Created tag" : "Etiqueta creada",
    "Failed to create tag" : "Fallo al crear etiqueta",
    "Updated tag" : "Etiqueta actualizada",
    "Failed to update tag" : "Fallo al actualizar la etiqueta",
    "Deleted tag" : "Etiqueta eliminada",
    "Failed to delete tag" : "Fallo al borrar etiqueta",
    "Create or edit tags" : "Crear o editar etiquetas",
    "Search for a tag to edit" : "Buscar la etiqueta a editar",
    "Collaborative tags …" : "Etiquetas colaborativas ...",
    "No tags to select" : "No hay etiquetas para seleccionar",
    "Tag name" : "Nombre de la etiqueta",
    "Tag level" : "Nivel de la etiqueta",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Delete" : "Borrar",
    "Reset" : "Restablecer",
    "Loading …" : "Cargando …",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} será establecida y {tag2} se eliminará de 1 archivo.","{tag1} será establecida y {tag2} será eliminada de {count} archivos.","{tag1} será establecida y {tag2} será eliminada de {count} archivos."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag}se establecerá en 1 archivo.","{tag} se establecerá en {count} archivos.","{tag} se establecerá en {count} archivos."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} se eliminará de 1 archivo.","{tag} se eliminará de {count} archivos.","{tag} se eliminará de {count} archivos."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} y {lastTag} se establecerán en 1 archivo.","{tags} y {lastTag} se establecerán en {count} archivos.","{tags} y {lastTag} se establecerán en {count} archivos."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} y {lastTag} serán eliminadas de 1 archivo.","{tags} y {lastTag} serán eliminadas de {count} archivos.","{tags} y {lastTag} serán eliminadas de {count} archivos."],
    "{displayName} (hidden)" : "{displayName} (oculto)",
    "{displayName} (restricted)" : "{displayName} (restringido) ",
    "Only admins can create new tags" : "Solo los administradores pueden crear etiquetas nuevas",
    "Failed to apply tags changes" : "Error al guardar los cambios de la etiqueta",
    "Manage tags" : "Gestionar etiquetas",
    "Applying tags changes…" : "Aplicando cambios a las etiquetas...",
    "Search or create tag" : "Buscar o crear etiqueta",
    "Search tag" : "Buscar etiqueta",
    "Change tag color" : "Cambiar color de etiqueta",
    "Create new tag" : "Crear nueva etiqueta",
    "Choose tags for the selected files" : "Escoja las etiquetas para los archivos seleccionados",
    "Cancel" : "Cancelar",
    "Apply" : "Aplicar",
    "Failed to load tags" : "Fallo al cargar etiquetas",
    "Failed to load selected tags" : "Fallo al cargar las etiquetas seleccionadas",
    "Failed to select tag" : "Fallo al seleccionar etiqueta",
    "System admin disabled tag creation. You can only use existing ones." : "El administrador del sistema ha desactivado la creación de etiquetas. Solo puedes usar las que ya existen.",
    "Loading collaborative tags …" : "Cargando etiquetas colaborativas …",
    "Search or create collaborative tags" : "Buscar o crear etiquetas colaborativas",
    "No tags to select, type to create a new tag" : "No hay etiquetas para seleccionar, escriba para crear una etiqueta nueva",
    "Unable to update setting" : "No se ha podido actualizar la configuración",
    "System tag creation is now restricted to administrators" : "La creación de etiquetas del sistema está limitada a administradores",
    "System tag creation is now allowed for everybody" : "Todos los usuarios pueden crear etiquetas del sistema",
    "System tag management" : "Administración de etiquetas del sistema",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Si está habilitado, sólo los administradores podrán crear y editar etiquetas. Las demás cuentas todavía serán capaces de asignarlas o eliminarlas de los archivos.",
    "Restrict tag creation and editing to administrators" : "Restringir la creación y edición de etiquetas a los administradores",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Las etiquetas colaborativas están disponibles para todos los usuarios. Las etiquetas restringidas son visibles para los usuarios, pero no pueden ser asignadas por ellos. Las etiquetas invisibles son para uso interno, pues los usuarios no pueden verlas ni asignarlas.",
    "Assigned collaborative tags" : "Etiquetas colaborativas asignadas",
    "Open in Files" : "Abrir en Archivos",
    "List of tags and their associated files and folders." : "Lista de etiquetas y sus carpetas y archivos asociados.",
    "No tags found" : "No se encontraron etiquetas",
    "Tags you have created will show up here." : "Las etiquetas que haya creado aparecerán aquí.",
    "Failed to load tag" : "Error al cargar etiqueta",
    "Failed to load last used tags" : "Fallo al cargar las etiquetas recientemente utilizadas",
    "Missing \"Content-Location\" header" : "Falta el encabezado \"Content-Location\"",
    "A tag with the same name already exists" : "Ya existe una etiqueta con el mismo nombre",
    "Failed to load tags for file" : "Fallo al cargar las etiquetas del archivo",
    "Failed to set tag for file" : "Fallo al asignar la etiqueta al archivo",
    "Failed to delete tag for file" : "Fallo al borrar la etiqueta del archivo",
    "File tags modification canceled" : "Modificación de las etiquetas del archivo cancelada",
    "Select or create tags to apply to all selected files" : "Selecciona o crea etiquetas para aplicar a los archivos seleccionados",
    "Select tags to apply to all selected files" : "Seleccione las etiquetas que se aplicarán a todos los archivos",
    "Apply changes" : "Aplicar cambios"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
